@@ -5,7 +5,7 @@ use v5.10;
 use Dist::Zilla;
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -16,11 +16,20 @@ sub configure
 {
   my($self) = @_;
 
-  $self->add_bundle('Filter' => {
-    -bundle => '@Basic',
-    -remove => [ qw( UploadToCPAN Readme ExtraTests ConfirmRelease ) ],
-  });
-
+  $self->add_plugins(
+    'GatherDir',
+    [ PruneCruft => { except => '.travis.yml' } ],
+    'ManifestSkip',
+    'MetaYAML',
+    'License',
+    'ExecDir',
+    'ShareDir',
+    'MakeMaker',
+    'Manifest',
+    'TestRelease',
+  );
+  
+  
   $self->add_plugins(qw(
 
     PodWeaver
@@ -48,6 +57,7 @@ sub configure
     
   $self->add_plugins(qw(
 
+    Author::Plicease::TransformTravis
     InstallGuide
     MinimumPerl
     ConfirmRelease
@@ -69,7 +79,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
@@ -81,12 +91,18 @@ In your dist.ini:
 
 This Dist::Zilla plugin bundle is the equivalent to
 
- [@Filter]
- -bundle = @Basic
- -remove = UploadToCPAN
- -remove = Readme
- -remove = ExtraTests
- -remove = ConfirmRelease
+ # Basic - UploadToCPAN, Readme, ExtraTests, and ConfirmRelease
+ [GatherDir]
+ [PruneCruft]
+ except = .travis.yml
+ [ManifestSkip]
+ [MetaYAML]
+ [License]
+ [ExecDir]
+ [ShareDir]
+ [MakeMaker]
+ [Manifest]
+ [TestRelease]
 
  [PodWeaver]
  [NextRelease]
@@ -104,9 +120,11 @@ This Dist::Zilla plugin bundle is the equivalent to
  repository.github = user:plicease
  homepage = http://perl.wdlabs.com/%{dist}/
  
+ [Author::Plicease::TransformTravis]
+ 
  [InstallGuide]
  [MinimumPerl]
- [ConfirmRelease]
+ [ConfirmRelease] 
 
 =head1 SEE ALSO
 
